pub struct CaptureRun {
pub id: String,
pub started_at: u64,
pub label: String,
pub cameras: Vec<CaptureCam>,
}Expand description
One capture run (a print’s recordings), newest first when listed.
Fields
id: StringThe run dir name, e.g. 1781634785_cube-petg2_gcode_3mf.
started_at: u64Unix epoch parsed from the dir name prefix (0 if unparseable).
label: StringThe human-ish remainder of the dir name (the sanitized job name).
cameras: Vec<CaptureCam>Trait Implementations
Sourceimpl Clone for CaptureRun
impl Clone for CaptureRun
Sourcefn clone(&self) -> CaptureRun
fn clone(&self) -> CaptureRun
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CaptureRun
impl Debug for CaptureRun
impl Eq for CaptureRun
Sourceimpl PartialEq for CaptureRun
impl PartialEq for CaptureRun
Sourcefn eq(&self, other: &CaptureRun) -> bool
fn eq(&self, other: &CaptureRun) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CaptureRun
impl Serialize for CaptureRun
impl StructuralPartialEq for CaptureRun