evaluate

Function evaluate 

pub fn evaluate(
    cmd: &Command,
    status: &PrinterStatus,
    baseline_print_error: Option<i64>,
) -> EffectStatus
Evaluate a command’s effect against the current status, given the baseline_print_error captured before the command was sent (so only a new error is reported, not a pre-existing one).